pro ydb_install, startt,  stopt, ydbsets=ydbsets, noexecute=noexecute, $
	default=default, ping=ping, debug=debug
;
;+
;   Name: ydb_install
;
;   Purpose: format and execute a ydb installation job
;
;   Calling Sequence:
;      ydb_install, starttime, stoptime			; menu select sets
;      ydb_install, starttime, stoptime, /default	; default sets
;     
;   Inputs:
;	starttime	Start time of interval
;	stoptime	Stop time of interval
;
;   Keyword Inputs:
;	default		Copy all with yes against them in configuration file
;			Over-ridden by list supplied in yssw_db_sets
;	noexecute	Write FTP file, but do not execute it
;	ping		Conduct "is alive" test on remote host using ping
;
;   History:
;      Circa: 1-Feb-1994 (SLF)
;      12-Dec-94 (RDB) Added "pubydb_config"  to allow other site to
;                      act as sources. used with "yssw_sw_host"
;                      login_info determined by "yssw_sw_host"
;       2-apr-95 (SLF) - allow index times for start/stop times 
;       5-may-1995 (SLF) - force all SFC (wide time window)
;      16-Nov-1999 (RDB) - Updated to use SSWDB anonymous ftp site
;      22-Jun-2000 (RDB) - made default sohoftp
;      
;   Restrictions: 
;	no preseravation of dates/ownership (need tar)
;       no disk space checking - can fill up disk quickly
;	no compare to existing files - (re-copies)
;
;	is alive test (ping) will not work through a firewall
;-

;>>	define the time range of interest

; start time = null - copy all files since last local one??????????
; stop time  = null - copy through today

case n_params() of
   0: begin
        startt=''
        read,'Enter start time: ',startt
        stopt=''
        read,'Enter stop time: ',stopt
        if stopt eq '' then stopt = systime()
   endcase
   1: stopt=timegrid(startt,/day)
   else:
endcase
    
strt=fmt_tim(startt)
stpt=fmt_tim(stopt)

   
if strt eq '' then message,'need start time...'

anytim2weeks,strt, stpt,years,weeks
weekstr=string(weeks,format='(i2.2)') + '_' + $
   	string(years,format='(i2.2)')

syears=string(years,format='(i2.2)')
if n_elements(syears) gt 1 then syears=syears(uniq(syears))

if keyword_set(debug) then print,'** Selected weeks: ',weekstr


;>>	define what file types are allowed (from configuration file)

;   if pubydb_config not defined, use default one for SolarSoft
config = getenv('pubydb_config')
if strlen(config) eq 0 then $
   config=concat_dir('$SSW_GEN','setup/sswdb_descriptions.dat')

print,'** Using config file: ',config
if not file_exist(config) then begin
   tbeep
   message,/info,'Need file: ' + config + ', please upgrade and retry...'
   return
endif else ydbdata=rd_tfile(config,delim=';',/nocomment,/auto)

nsets=n_elements(ydbdata(0,*))

;	keyword /default will cause all flagged files to be copied

if keyword_set(default) then begin
   ydbsets = reform(ydbdata(1,where(reform(ydbdata(3,*)) eq 'yes')))
endif

;	Otherwise, try those defined in "yssw_db_sets" or use menu
if n_elements(ydbsets) eq 0 then begin
   chkenv=str2arr(get_logenv('yssw_db_sets'),' ')
   if chkenv(0) eq '' then begin
      message,/info,'Select data base types from menu...'
      ss=wmenu_sel(strupcase(ydbdata(1,*)) + ' : ' + ydbdata(4,*))
      if ss(0) eq -1 then begin
         message,/info,'Nothing selected, quitting...
	 return
      endif
      chkenv=ydbdata(1,ss)
   endif
   ydbsets=chkenv
endif 
Print,'** Requested Datasets: ',ydbsets


;>>	by now should have a list of required files

;	check all valid datasets
allsets=reform(ydbdata(1,*))
which=where_arr(allsets,ydbsets,sscnt)
if nsets ne sscnt then begin
   box_message,['WARNING: SOME Datasets not copied']
endif

if sscnt eq 0 then begin
   message,/info,"Could not determine ydb sets selected"
   return
endif

;>>	define the information for the designated FTP site

;;ydbget=''

DefinedHost = get_logenv('yssw_sw_host')
SOHOftp = 0
if DefinedHost eq 'sohoftp.nascom.nasa.gov' then SOHOftp = 1

if DefinedHost ne '' then begin
   swhost = DefinedHost
   login_info = 'user ftp ' + get_user() + "@" + get_host()
   remote_root = '/pub/'
   if SOHOftp then remote_root = '/sdb/'

endif else begin
;;;	this will not work - account dissabled...
;;   swhost = 'isass0.solar.isas.ac.jp'
;;   login_info = 'user guest ##Machida'
;;   remote_root = '/pub/'

;	default to sohoftp at GSFC
   swhost = 'sohoftp.nascom.nasa.gov'
   login_info = 'user ftp ' + get_user() + "@" + get_host()
   remote_root = '/sdb/'

endelse

print,'** Using host: ',swhost

;	PING test will probably not work through a firewall!!!!!
if keyword_set(ping) then begin
   print,'** Checking host is alive: ',swhost
   if not is_alive(swhost) then begin
      tbeep
      message,/info,"FTP HOST: " + swhost + " is not responding, try again later.."
      return
   endif
endif

;>>	define remote dataset directories

ydbdata = ydbdata(*,which)
ydbenv = reform(ydbdata(0,*))		;env. vars of where data stored
ydbsets = reform(ydbdata(1,*))		;dataset prefix
remote = reform(ydbdata(2,*))		;remote directory where stored (ISAS)
;??	set a default if remote directory not defined
remss=where(remote eq '',rsscnt)
if rsscnt gt 0 then remote(remss)='/ydb/' + ydbsets(remss)

remote = remote_root + remote
;;if SOHOftp then remote = remote_root + reform(ydbdata(1,*))


;>>	define local dataset addresses

locals=''
nsets=n_elements(ydbsets)

;	define local storage by env. variables so that user can put
;	the retrieved file where they want them...
for sets=0,sscnt-1  do begin
   local=get_logenv(ydbenv(sets),/case_ignor)
   locals=[locals,local]
endfor   
locals=locals(1:*)


Print,'** Copied Datasets: ',ydbsets

if keyword_set(debug) then begin
   print,remote
   print,locals
endif


;>>	build the FTP file   

ftpfile=concat_dir(getenv('HOME'),'ydbget.ftp')
print,'** Writing FTP script: ',ftpfile
file_append,ftpfile,/new, [				$
   'open ' + 	swhost,					$
   login_info,                                          $
   'binary'						]

for set=0,nsets-1 do begin
   ydbfiles=ydbsets(set)+weekstr+ '*.*'
;  *** kludge for special cases ***
   if ydbsets(set) eq 'sfc' then ydbfiles=ydbsets(set) + '*.*'
   file_append,ftpfile, [				$
        'lcd ' + locals(set), 				$
;;;	'cd ' + '/pub/ydb/' + remote(set),		$
	'cd ' + remote(set),		$ ;*** temporary
	'mget ' + ydbfiles				]   
endfor

file_append,ftpfile,'bye'

if keyword_set(debug) then stop

;>>	Now execute the FTP retrieval

if not keyword_set(noexecute) then begin
   for dir=0,n_elements(locals)-1 do begin
      if not file_exist(locals(dir)) then begin
         message,/info,'Creating directory: ' + locals(dir)
         spawn,'mkdir -p ' + locals(dir),reply
         if not file_exist(locals(dir)) then begin
            tbeep
            message,/info,'COULD NOT MAKE DIRECTORY - CHECK PROTECTION ON YDB'
            message,/info,'Returning.... (no ftps done)
            return
         endif
      endif
   endfor
   print,'** Executing FTP script: ',ftpfile
   spawn,'ftp -in < ' + ftpfile, ftpres
   if ftpres(0) ne '' then prstr,['From ftp...',ftpres]
endif

return
end

